/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import java.io.File;
import javax.servlet.http.*;
import com.ibm.workflow.api.*;
import com.ibm.workflow.servlet.client.*;

/**
* This class povides a function of navigating multiple JSPs.
*/
public class ChangePageHandler extends WExtCommandHandler {
    /**
    * Returns information about the handler.
    * @return   a String containing handler information
    */
    public String getHandlerInfo() {
        return "MQWF WebClient Extentions V1.0 - ChangePageHandler";
    }

    /**
    * Initializes the handler.
    * @param config     the servlet's configuration and initialization parameters
    */
    public void init(Config cfg) {
        super.init(cfg);
        getContext().log("init ChangePageHandler", false);
    }


    /**
    * This custom command retrieves page information from PageController session bean,
    * and return the new page.
    * @param request        the request the client has made of the servlet
    * @param response       the response the servlet sends to the client
    * @return               the result page to be sent to the client
    */
    public ResponsePage changePage(HttpServletRequest request,
                            HttpServletResponse response) throws ClientException {
        getContext().log("changePage called.", false);

        try {
            SessionContext sc = getSessionContext(request);
            BuiltinHandler bh = sc.getBuiltinHandler();
            PageController controller = getPageController(request);
            if (controller == null) {
                getContext().log("  Cannot get session ", false);
                throw new ClientException(request, "No PageController");
            }

            RequestContext context = new RequestContext(request);
            String id = request.getParameter("id");
            String pid = request.getParameter(getPageId());
            WorkItem wi = sc.getWorkItem(sc.getWorkListOid(), id);
            context.setWorkItem(wi);
            context.setContainer(wi.inContainer());

            if (wi == null) {
                getContext().log("  Workitem " + id + " not found.", false);
                throw new ClientException(request, context.get("Error.WorkItemNotFound", id));
            }

            ReadWriteContainer container = wi.outContainer();
            PostedValues values = new PostedValues(request);

            // queryPageChange
            ResponsePage page = null;
            Object listener = controller.getEventListener();
            if (listener instanceof PageChangeEventListener) {
                page = ((PageChangeEventListener)listener).queryPageChange(context, controller, values);
            } else if (listener != null) {
                page = invokeEventListener(listener, "queryPageChange", context, controller, values);
            }
            if (page != null) {
                getContext().log(" abort changePage", false);
                request.setAttribute(getDataBeanId(), controller.getReuseData());
                return page;
            }

            controller.setPostedValues(values);

            String pagefile = controller.getPage(pid);
            if (pagefile != null && pagefile.endsWith(".jsp")) {
                File jspFile = new File(getContext().getDocumentRoot(), pagefile);
                if (jspFile.isFile()) {
                    controller.setCurrentPage(pagefile);
                    page = new ResponsePage(context, pagefile);
                } else {
                    getContext().log("page " + pagefile + " missing.", false);
                }
            } else {
                getContext().log("page " + pagefile + " is not jsp.", false);
            }
            if (page == null) {
                controller.setCurrentPage(null);
                page = bh.render("checkOutWorkItem", context);
            }

            request.setAttribute(getDataBeanId(), controller.getReuseData());

            getContext().log("changePage done.", false);
            return page;
        }
        catch (FmcException ex) {
            throw new ClientException(request, ex);
        }
    }
}

