/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import com.ibm.workflow.servlet.client.*;

/**
* This is queryCheckInWorkItem event and postCheckInWorkItem event listener interface.
* Application developers can implement listener method without this interface.
* But this is useful for compile error checking.
*/
public interface CheckInWorkItemEventListener {
    /**
    * Invoked when a work item just before check-in.
    * @param context    a RequestContext object
    * @param controller a PageController session bean object
    * @param values     a PostedValues object
    * @return           a ResponsePage object
    * @exception ClientException if an error occurred
    */
    ResponsePage queryCheckInWorkItem(RequestContext context, PageController controller, PostedValues values) throws ClientException;

    /**
    * Invoked when a work item has been checked-in.
    * @param context    a RequestContext object
    * @param controller a PageController session bean object
    * @return           a ResponsePage object
    * @exception ClientException if an error occurred
    */
    ResponsePage postCheckInWorkItem(RequestContext context, PageController controller) throws ClientException;
}
