/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import java.util.*;
import com.ibm.workflow.api.*;
import com.ibm.workflow.servlet.client.*;

/**
* This class is a data store of process instance InputCounainer
* and work item OutputContainer.
*/
public class ReuseData implements java.io.Serializable {
    Hashtable table;
    ReadWriteContainer container;
    boolean isDraft;

    /**
    * Constructor.
    */
    public ReuseData() {
    }

    /**
    * Constructor.
    * @param container  a ReadWriteContainer for re-use
    * @param context    a RequestContext for invoke getMemberValue
    */
    public ReuseData(ReadWriteContainer container, RequestContext context) {
        this.container = container;
        table = new Hashtable();
        try {
            appendElements(context, "", container.structMembers());
        } catch (FmcException ex) {
        }
    }

    /**
    * Returns an an ReadWriteContainer of original container.
    * @param container  an original ReadWriteContainer object
    */
    public ReadWriteContainer getOriginalContainer() {
        return container;
    }

    protected void setDraftSaved(boolean flag) {
        isDraft = flag;
    }

    /**
    * Returns a boolean indicating whether the original data is draft saved.
    * @return   a boolean indicating data is draft saved.
    */
    public boolean isDraftSaved() {
        return isDraft;
    }

    /**
    * Returns a boolean indicating whether the original data is not null.
    * @return   a boolean indicating re-use data is available
    */
    public boolean isAvailable() {
        return table != null;
    }

    /**
    * Sets the value with the specified item name.
    * @param item   the item name.
    * @param value  the value.
    */
    public void setValue(String item, String value) {
        if (table == null)
            table = new Hashtable();

        if (item == null || item.length() == 0)
            return;

        if (value == null)
            table.remove(item);
        else
            table.put(item, value);
    }

    /**
    * Returns the value to which the specified item name.
    * @param item   the item name.
    * @return       the item value
    */
    public String getValue(String item) {
        if (table == null || item == null || item.length() == 0)
            return "";
        Object obj = table.get(item);
        if (obj == null)
            return "";
        return String.valueOf(obj);
    }

    /**
    * Returns the HTML valid string value to which the specified item name.
    * @param item   the item name.
    * @return       the item value
    */
    public String getHTMLValue(String item) {
        return RequestContext.toHTMLText(getValue(item), "");
    }

    /**
    * Returns an Enumeration object of item names.
    * @return an Enumeration object of item names
    */
    public Enumeration getItems() {
        if (table == null)
            return null;
        return table.keys();
    }

    protected void appendElements(RequestContext context, String structName, ContainerElement[] elements) throws FmcException {
        for (int i = 0; elements != null && i < elements.length; ++i) {
            ContainerElement element = elements[i];
            String itemname = element.name();

            if (structName != null && structName.length() > 0)
                itemname = structName + "." + itemname;

            if (!element.isArray())
                appendElementData(context, itemname, element);
            else {
                ContainerElement[] elems = element.arrayElements();
                for (int j = 0; elems != null && j < elems.length; j++) {
                    appendElementData(context, itemname + "[" + j + "]", elems[j]);
                }
            }
        }
    }

    protected void appendElementData(RequestContext context, String itemname, ContainerElement element) throws FmcException {
        if (element.isStruct()) {
            appendElements(context, itemname, element.structMembers());
            return;
        }
        String itemvalue = context.getMemberValue(element, "");
        if (itemvalue != null && itemvalue.length() > 0)
            table.put(itemname, itemvalue);
    }
}
