/************************************************************************/
/*                                                                      */
/*  Licensed Materials - Property of IBM                                */
/*  WA84 SupportPac                                                     */
/*  (c) Copyright IBM Corp. 2001                                        */
/*  US Government Users Restricted Rights - Use, duplication or         */
/*  disclosure restricted by GSA ADP Schedule Contract                  */
/*  with IBM Corp.                                                      */
/*                                                                      */
/************************************************************************/
package com.ibm.workflow.servlet.clientx.wext;

import com.ibm.workflow.servlet.client.*;

/**
* This class is extended from Command class.
* This class handle WExtResource.properties resource for commandText
*/
public class WExtCommand {
    private String commandString;
    private String commandPicture;
    private String commandText;

    /**
    * Constructs a Command object.
    * @param commandString  the command to be invoked
    * @param commandPicture the name of the .gif file to be shown
    * @param commandText    the description of the command
    */
    public WExtCommand(String commandString, String commandPicture, String commandText) {
        this.commandString = commandString;
        this.commandPicture = commandPicture;
        this.commandText = commandText;
    }

    /**
    * Construct a HTML anchor (a href) tag and icon (img) that will cause the command to be executed.
    * @param context    the request context
    * @param id         the OID of the object on which the command should be invoked
    * @param name       the name of the object (only used in JavaScript prompts)
    * @return           a HTML a href tag
    */
    public String getTriggerTag(RequestContext context, String id, String name) {
        return "<a href=\""
                + context.getCommand(commandString, id)
                + "\"><img src=\""
                + context.getURL("{_HTMLDir_}/images/action/" + commandPicture)
                + "\" border=\"0\" alt=\""
                + getText(context)
                + "\"></a>";
    }

    /**
    * Query the command's text that can be used as alt text or as button label.
    * @param context    the context to be used for localized strings
    * @return           the command's text
    */
    public String getText(RequestContext context) {
        Catalog cat = context.getCatalog("com.ibm.workflow.servlet.clientx.wext.WExtResource");
        String text = null;
        if (cat != null)
            text = cat.get(commandText);
        if (text == null)
            text = commandText;
        return text;
    }
}
